@@ -1,8 +1,8 @@
-__version__      = '0.2.2'
+__version__      = '0.2.4'
 __license__      = 'MIT'
 __author__       = 'Yohei Osawa'
 __author_email__ = 'yohei.osawa.318.niko8@gmail.com'
-__url__          = 'https://github.com/yohei250r/pymcprotocol'
+__url__          = 'https://github.com/senrust/pymcprotocol'
 
 from .type3e import Type3E
 from .type4e import Type4E
\ No newline at end of file
